/* This code represents a dimming operation via phase cut control logic. 
 * For phase cut logic, modify appropriate register addresses.
 *  1. Enable Software Enable 
 *  2. Start watchdog timer and toggle before 655ms
 *  3. Modify phase cut register address 
 */
 
// Phase Cut Control Application

#include <Wire.h>                                             // Include library for I2C communication

byte Data;
int count = 0x4E;                                             // Start count to turn TRIAC ON
int count1 = 0x20;

void setup() 
{
  Wire.begin();                                               // Initiate Wire library and join I2C bus as a master
  Serial.begin(9600);                                         // Open serial port and set data rate to 9600 bps for serial communication

}

void loop() 
{
 
  // Phase Cut Control Logic  

    for (int i=1; i<=65535; i++)
    {
      writeI2C8(0x08, 0x4C, 0x01);                            // enable software enable
      delay (10);
      writeI2C8(0x08, 0x4C, 0x02);                            // enable watchdog timer
      delay(10);
      writeI2C(0x08, 0x95, count, count1);                    // Write counter data for phase cut control 
      delay(50);
      count++;
      count1++;                                               // Increment count to monitor phase cut feature
      delay(10);
      writeI2C8(0x08, 0x4C, 0x01);                            // toggle watchdog timer
      delay(10);

      if (count == 0xFF & count1 == 0xFF)                     // Stop counter data at count= 0xFF and count1=0xFF
      {
        delay(20);
        count = 0x4E;                                         // After 2 seconds, set the counter data to start count value
        count1 = 0x20;
      }
      Data = readI2C(0x08, 0x95, 2);                          // Read each counter value
      //Serial.println(Data);
    }
}

// I2C 8-bit Read Function
int readI2C8(byte Slave_Device_Add, byte Reg_Add)
{
  byte Read_Data;
  Wire.beginTransmission(Slave_Device_Add);                   // Start I2C read with Slave Device Address
  Wire.write(Reg_Add);                                        // Write Register Address
  Wire.endTransmission(false);                                // End Transmission
  Wire.requestFrom(Slave_Device_Add, 1);                      // Read Bytes from Register Address
  while(Wire.available())
  {
    Read_Data = Wire.read();                                  // Read Data
  }
  return Read_Data;
}

//I2C 8-bit Write Function
void writeI2C8(byte Slave_Add, byte Reg_Add, byte Write_Data) 
{
  Wire.beginTransmission(Slave_Add);                          // Start I2C write with Slave Device Address
  Wire.write(Reg_Add);                                        // Write Redister Address
  Wire.write(Write_Data);                                     // Write Data
  Wire.endTransmission();                                     // End Transmission
}

// I2C 16-bit Read Function
int readI2C(byte Slave_Device_Add, byte Reg_Add, int No_of_Bytes)
{
  uint16_t Read_Data;
  Wire.beginTransmission(Slave_Device_Add);                   // Start I2C read with Slave Device Address
  Wire.write(Reg_Add);                                        // Write Register Address
  Wire.endTransmission(false);                                // End Transmission
  Wire.requestFrom(Slave_Device_Add, No_of_Bytes, true);      // Read Bytes from Register Address
  while(Wire.available())
  {
    Read_Data = Wire.read();                                  // First Read LSB Byte  
    Read_Data |= (Wire.read() << 8);                          // Read 16-bits 
  }
  //delay(500);
  return Read_Data;
}

//I2C 16-bit Write Function
void writeI2C(byte Slave_Add, byte Reg_Add, int Write_Data_1, int Write_Data_2) 
{
  Wire.beginTransmission(Slave_Add);                          // Start I2C write with Slave Device Address
  Wire.write(Reg_Add);                                        // Write Redister Address
  Wire.write(Write_Data_1);                                   // Write LSB Byte of 16-bit counter 
  Wire.write(Write_Data_2);                                   // Write MSB Byte of 16-bit counter
  Wire.endTransmission();                                     // End Transmission
